#
# spec file for package libcec
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Guillaume GARDET <guillaume@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libcec3
%bcond_with enable_rpi_build
Name:           libcec
Version:        3.1.0
Release:        3.1
Summary:        Control your device with your TV remote control via HDMI
License:        GPL-2.0+
Group:          Hardware/TV
Url:            https://github.com/Pulse-Eight/libcec
Source:         https://github.com/Pulse-Eight/libcec/archive/libcec-%{version}.tar.gz
Patch1:         %{name}-cmake_install_lib_dir.patch
Patch123:       libcec-build-compare.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libXrandr-devel
BuildRequires:  libudev-devel
BuildRequires:  lockdev-devel
BuildRequires:  ncurses-devel
BuildRequires:  p8-platform-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  swig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
BuildRequires:  raspberrypi-gfx-devel
%endif
%endif

%description
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

%package -n cec-client
Summary:        Control your device with your TV remote control via HDMI
Group:          Hardware/TV
Requires:       %{lname} = %{version}-%{release}

%description -n cec-client
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This package contains client applications

%package -n python-%{name}
Summary:        Python bindings for %{name}
Group:          Hardware/TV
%py_requires

%description -n python-%{name}
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This package contains python bindings

%package -n %{lname}
Summary:        USB CEC adapter communication library
Group:          System/Libraries

%description -n %{lname}
libCEC allows you, in combination with the right hardware, to control
your device with your TV remote control utilizing your existing HDMI
cabling.

%package devel
Summary:        Development files for the USB CEC adapter communication library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
libCEC is an enabling platform for the CEC bus in HDMI, it allows
developers to interact with other HDMI devices without having to
worry about the communication overhead, handshaking, and the various
ways of sending a message for each vendor.

This subpackage contains the headers for libcec.

%prep
%setup -q -n libcec-libcec-%{version}
%patch1
%patch123 -p1

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install
# dist-packages is debian specific location, we don't want to use it
install -d %{buildroot}%{python_sitearch}
mv %{buildroot}%{_libdir}/python2.7/dist-packages %{buildroot}%{python_sitearch}

%post   -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n cec-client
%defattr(755,root,root)
%{_bindir}/cec-client
%{_bindir}/cec-client-%{version}
%{_bindir}/cecc-client
%{_bindir}/cecc-client-%{version}

%files -n python-%{name}
%defattr(-,root,root)
%attr(755,root,root) %{_bindir}/pyCecClient.py
%{python_sitearch}/*

%files -n %{lname}
%defattr(-,root,root)
%{_libdir}/libcec.so.3*

%files devel
%defattr(-,root,root)
%{_includedir}/libcec
%{_libdir}/pkgconfig/libcec.pc
%{_libdir}/libcec.so

%changelog
* Mon Jan 25 2016 olaf@aepfle.de
- Reduce build-compare noise
  libcec-build-compare.patch
* Sat Jan 23 2016 mpluskal@suse.com
- Rename cmake_install_lib_dir.patch to
  libcec-cmake_install_lib_dir.patch
* Sat Jan 23 2016 sagiben@gmail.com
- Update to v3.1.0
- Add cmake_install_lib_dir.patch patch for better handling
  of libdir in .pc file and python packge installation path
- Update dependency to libp8-platform
* Sat Jan  2 2016 mpluskal@suse.com
- Fix path to libdir in .pc file (boo#960475)
* Mon Nov 16 2015 christof.hanke@induhviduals.de
- Explictly require package libcec by package cec-client since the
  library is loaded via dlopen.
* Sat Jul 18 2015 mpluskal@suse.com
- Update to 3.0.1
  * no upstream changelog provided
* Fri Jun 12 2015 mpluskal@suse.com
- Revert name change
- Use %%cmake macro
- Cleanup spec file with spec-cleaner
- Use url for source
- Fix non stanard changelog entry
- Split python package
- Update dependencies (add swig, drop autotools)
- libcec-no-buildtime.patch and configure.ac.diff were dropped by
  previous change
- Update name of source dir
* Mon Jun  1 2015 sagiben@gmail.com
- Update to v3.0.0
* Mon Feb  2 2015 olaf@aepfle.de
- Remove timestamps from binary to reduce build-compare noise
  libcec-no-buildtime.patch
* Thu Dec 25 2014 jengelh@inai.de
- Implement shared library packaging guidelines
* Wed Nov 26 2014 sagiben@gmail.com
- Update to v2.2.0
* Mon Sep 16 2013 guillaume@opensuse.org
- Remove old tar.gz from 2.1.1 version
* Tue Sep  3 2013 guillaume@opensuse.org
- Cleanup for submition to devel project:
  * clean section removed
  * --disable-static option added and remove libcec.la
  * make use of paralel build: "make %%{?_smp_mflags}"
* Mon Aug 26 2013 guillaume@opensuse.org
- Add '%%bcond_with enable_rpi_build' for armv6
* Mon Aug 26 2013 guillaume@opensuse.org
- Update to v2.1.3
* Thu Mar 21 2013 guillaume@opensuse.org
- Update to v2.1.1
* Tue Dec 11 2012 guillaume@opensuse.org
- Update to v2.0.5 (repacked version)
* Fri Oct 19 2012 guillaume@opensuse.org
- Initial Release (v2.0.4)
